module Diakonos
  module Functions

    def hello_world
      @buffer_current.paste "Hello, world!"
    end

  end
end